@@ -31,3 +31,13 @@ PACKAGES = {
 }
 
 install_packages_on(hosts, PACKAGES)
+
+agents.each do |agent|
+  if agent['platform'] =~ /windows/
+    arch = agent[:ruby_arch] || 'x86'
+    base_url = ENV['MSI_BASE_URL'] || "http://builds.puppetlabs.lan/puppet-agent/#{ENV['SHA']}/artifacts/windows"
+    filename = ENV['MSI_FILENAME'] || "puppet-agent-#{arch}.msi"
+
+    install_puppet_from_msi(agent, :url => "#{base_url}/#{filename}")
+  end
+end
