@@ -3,6 +3,8 @@
 # Purpose:
 #   Return the details of the disk partitions.
 #
+#   This fact is structured. Values are returned as a group of key-value pairs.
+#
 # Resolution:
 #   Parse the contents of `/sys/block/<device>/size` to receive the size (multiplying by 512 to correct for blocks-to-bytes).
 #
@@ -27,6 +29,7 @@ Facter.add(:partitions) do
       details['uuid']       = Facter::Util::Partitions.uuid(part)
       details['size']       = Facter::Util::Partitions.size(part)
       details['mount']      = Facter::Util::Partitions.mount(part)
+      details['label']      = Facter::Util::Partitions.label(part)
       details['filesystem'] = Facter::Util::Partitions.filesystem(part)
       details.reject! {|k,v| v.nil? || v.to_s.empty? }
       partitions[part] = details
