@@ -4,8 +4,8 @@
 #   Additional Facts about the machine's CPUs.
 #
 # Resolution:
-#   Utilizes values from the processors structured fact, which itself 
-#   uses various methods to collect CPU information, with implementation 
+#   Utilizes values from the processors structured fact, which itself
+#   uses various methods to collect CPU information, with implementation
 #   dependent upon the OS of the system in question.
 #
 # Caveats:
@@ -37,7 +37,7 @@ Facter.add("ProcessorCount") do
 
   setcode do
     if (processorcount = processors["count"])
-      processorcount.to_s
+      processorcount
     else
       nil
     end
