@@ -11,8 +11,8 @@
 Facter.add(:puppetversion) do
   setcode do
     begin
-      require 'puppet'
-      Puppet::PUPPETVERSION.to_s
+      require 'puppet/version'
+      Puppet.version.to_s
     rescue LoadError
       nil
     end
