@@ -1,15 +1,18 @@
-# Purpose: Determine information about Rackspace cloud instances
+# Fact: rsc_<RACKSPACE INSTANCE DATA>
+#
+# Purpose: Determine information about Rackspace cloud instances.
 #
 # Resolution:
-#   If this is a Rackspace Cloud instance, populates rsc_ facts
+#   If this is a Rackspace Cloud instance, populates `rsc_` facts: `is_rsc`, `rsc_region`,
+#   and `rsc_instance_id`.
 #
 # Caveats:
-#   Depends on Xenstore
+#   Depends on Xenstore.
 #
 
 Facter.add(:is_rsc) do
   setcode do
-    result = Facter::Util::Resolution.exec("/usr/bin/xenstore-read vm-data/provider_data/provider")
+    result = Facter::Util::Resolution.exec("/usr/bin/xenstore-read vm-data/provider_data/provider 2> /dev/null")
     if result == "Rackspace"
       "true"
     end
@@ -19,7 +22,7 @@ end
 Facter.add(:rsc_region) do
   confine :is_rsc => "true"
   setcode do
-    Facter::Util::Resolution.exec("/usr/bin/xenstore-read vm-data/provider_data/region")
+    Facter::Util::Resolution.exec("/usr/bin/xenstore-read vm-data/provider_data/region 2> /dev/null")
   end
 end
 
