@@ -4,6 +4,8 @@ require 'facter/util/loader'
 
 # Manage which facts exist and how we access them.  Largely just a wrapper
 # around a hash of facts.
+#
+# @api private
 class Facter::Util::Collection
 
   def initialize(internal_loader, external_loader)
@@ -12,53 +14,40 @@ class Facter::Util::Collection
     @external_loader = external_loader
   end
 
-  # Return a fact object by name.  If you use this, you still have to call
-  # 'value' on it to retrieve the actual value.
+  # Return a fact object by name.
   def [](name)
     value(name)
   end
 
-  # Add a resolution mechanism for a named fact.  This does not distinguish
-  # between adding a new fact and adding a new way to resolve a fact.
-  def add(name, options = {}, &block)
-    name = canonicalize(name)
-
-    unless fact = @facts[name]
-      fact = Facter::Util::Fact.new(name)
-
-      @facts[name] = fact
-    end
-
-    # Set any fact-appropriate options.
-    options.each do |opt, value|
-      method = opt.to_s + "="
-      if fact.respond_to?(method)
-        fact.send(method, value)
-        options.delete(opt)
-      end
-    end
+  # Define a new fact or extend an existing fact.
+  #
+  # @param name [Symbol] The name of the fact to define
+  # @param options [Hash] A hash of options to set on the fact
+  #
+  # @return [Facter::Util::Fact] The fact that was defined
+  def define_fact(name, options = {}, &block)
+    fact = create_or_return_fact(name, options)
 
     if block_given?
-      resolve = fact.add(&block)
-    else
-      resolve = fact.add
+      fact.instance_eval(&block)
     end
 
-    # Set any resolve-appropriate options
-    if resolve
-      # If the resolve was actually added, set any resolve-appropriate options
-      options.each do |opt, value|
-        method = opt.to_s + "="
-        if resolve.respond_to?(method)
-          resolve.send(method, value)
-          options.delete(opt)
-        end
-      end
-    end
+    fact
+  rescue => e
+    Facter.log_exception(e, "Unable to add fact #{name}: #{e}")
+  end
 
-    unless options.empty?
-      raise ArgumentError, "Invalid facter option(s) %s" % options.keys.collect { |k| k.to_s }.join(",")
-    end
+  # Add a resolution mechanism for a named fact.  This does not distinguish
+  # between adding a new fact and adding a new way to resolve a fact.
+  #
+  # @param name [Symbol] The name of the fact to define
+  # @param options [Hash] A hash of options to set on the fact and resolution
+  #
+  # @return [Facter::Util::Fact] The fact that was defined
+  def add(name, options = {}, &block)
+    fact = create_or_return_fact(name, options)
+
+    fact.add(options, &block)
 
     return fact
   end
@@ -144,6 +133,21 @@ class Facter::Util::Collection
 
   private
 
+  def create_or_return_fact(name, options)
+    name = canonicalize(name)
+
+    fact = @facts[name]
+
+    if fact.nil?
+      fact = Facter::Util::Fact.new(name, options)
+      @facts[name] = fact
+    else
+      fact.extract_ldapname_option!(options)
+    end
+
+    fact
+  end
+
   def canonicalize(name)
     name.to_s.downcase.to_sym
   end
