@@ -13,9 +13,17 @@ module Facter::Util::Virtual
   # and later versions of virt-what may emit this message on stderr. This
   # method ensures stderr is redirected and that error messages are stripped
   # from stdout.
-  def self.virt_what(command = "virt-what")
-    command = Facter::Core::Execution.which(command)
-    return unless command
+  def self.virt_what(cmd = "virt-what")
+    if bindir = Facter::Util::Config.override_binary_dir
+      command = Facter::Core::Execution.which(File.join(bindir, cmd))
+    else
+      command = nil
+    end
+
+    if !command
+      command = Facter::Core::Execution.which(cmd)
+      return unless command
+    end
 
     if Facter.value(:kernel) == 'windows'
       redirected_cmd = "#{command} 2>NUL"
@@ -153,7 +161,13 @@ module Facter::Util::Virtual
   def self.lxc?
     path = Pathname.new('/proc/1/cgroup')
     return false unless path.readable?
-    in_lxc = path.readlines.any? {|l| l.split(":")[2].to_s.start_with? '/lxc/' }
+    begin
+      in_lxc = path.readlines.any? {|l| l.split(":")[2].to_s.include? '/lxc' }
+    rescue Errno::EPERM => exc
+      # If we get "operation not permitted" here, it probably means we are
+      # running OpenVZ. We are not running LXC anyway, so...
+      return false
+    end
     return true if in_lxc
     return false
   end
@@ -164,7 +178,12 @@ module Facter::Util::Virtual
   def self.docker?
     path = Pathname.new('/proc/1/cgroup')
     return false unless path.readable?
-    in_docker = path.readlines.any? {|l| l.split(":")[2].to_s.start_with? '/docker/' }
+    begin
+      in_docker = path.readlines.any? {|l| l.split(":")[2].to_s.include? '/docker' }
+    rescue Errno::EPERM => exc
+      # This can fail under OpenVZ, just like in .lxc?
+      return false
+    end
     return true if in_docker
     return false
   end
