@@ -1,4 +1,4 @@
-#! /usr/bin/env ruby -S rspec
+#! /usr/bin/env ruby
 
 require 'spec_helper'
 
@@ -14,7 +14,7 @@ describe 'Filesystem facts' do
     before :each do
       Facter.fact(:kernel).stubs(:value).returns('Linux')
       fixture_data = my_fixture_read('linux')
-      Facter::Util::Resolution.expects(:exec) \
+      Facter::Core::Execution.expects(:exec) \
         .with('cat /proc/filesystems 2> /dev/null').returns(fixture_data)
       Facter.collection.internal_loader.load(:filesystems)
     end
