@@ -12,7 +12,7 @@ describe "id fact" do
       it "should return the current user" do
         given_a_configuration_of(:is_windows => k == 'windows')
         Facter.fact(:kernel).stubs(:value).returns(k)
-        Facter::Core::Execution.expects(:exec).once.with('whoami', anything).returns 'bar'
+        Facter::Core::Execution.expects(:execute).once.with('whoami', anything).returns 'bar'
 
         Facter.fact(:id).value.should == 'bar'
       end
@@ -21,8 +21,8 @@ describe "id fact" do
 
   it "should return the current user on Solaris" do
     given_a_configuration_of(:is_windows => false)
-    Facter::Core::Execution.stubs(:exec).with('uname -s').returns('SunOS')
-    Facter::Core::Execution.expects(:exec).once.with('/usr/xpg4/bin/id -un', anything).returns 'bar'
+    Facter.fact(:kernel).stubs(:value).returns 'SunOS'
+    Facter::Core::Execution.expects(:execute).once.with('/usr/xpg4/bin/id -un', anything).returns 'bar'
 
     Facter.fact(:id).value.should == 'bar'
   end
