@@ -91,6 +91,8 @@ describe "The macaddress fact" do
 
     before :each do
       Facter.fact(:kernel).stubs(:value).returns('windows')
+      Facter.fact(:operatingsystem).stubs(:value).returns('windows')
+      Facter.fact(:osfamily).stubs(:value).returns('windows')
       Facter::Util::Registry.stubs(:hklm_read).returns(nic_bindings)
     end
 
